/*******************************************************************************
 Project:
 	TW-RMSDC
 Descriptions:
 	This firmware is for controlling TW-RMSDC
 	IDE: MPLAB IDE v8.92
 	Compiler: PIC C18
 	Copyright(C) 2016 Akihiro Kawata, Triple W Japan KK.
 	Last Update by A.KAWATA, 3/31/2017
********************************************************************************/
#include <p18f24j10.h>
#include "CTRLio.h"

/*******************************************************************************
 Define function's pointer: func_sw[] is defined in CTRLio.c
********************************************************************************/
extern RANGE func_sw[];

/*******************************************************************************
 Configuration Bits
********************************************************************************/
#pragma config WDTEN = OFF		// WATCH DOG TIMER --
#pragma config STVREN = OFF		// Reset on stack overflow/underflow disabled
#pragma config XINST = ON		// Instruction set extension and Indexed Addressing mode enable
#pragma config DEBUG = OFF		// Background debugger disabled; RB6 and RB7 configured as GPIO pins
#pragma config CP0 = OFF		// Program memory is not code-protected
//pragma config FOSC = HS		// HS oscillator
#pragma config FOSC2 = OFF		// INTRC enabled as system clock when OSCCON<1:0> = 00
#pragma config FCMEN = ON		// Fail-Safe Clock Monitor enabled
#pragma config WDTPS = 1		// 1,2,4...32768 WATCH DOG POST SCALER
#pragma config CCP2MX = DEFAULT	// CCP2 is multiplexed with RC1

void main(void)
{
	OSCCON = 0x00;	// INTRC 31kHz, SCS=00(InternalClock)
	ADCON1 = 0x0F;	// RA0-5 : Digital I/O Enabled
					// RB0-4 : Digital I/O Enabled

	// Port Definition for PIC.
	// 1: Input
	// 0: Output
	TRISA = 0xF0;	// RA0-3 : Output, RA4-7: Input
	TRISB = 0x1E;	// RB0   : Output is dummy
					// RB1-4 : Input
					// RB5   : Output
	TRISC = 0x00;	// RC0-3 : Output for Relay Driver
					// RC4-7 : Output is dummy
	LATA = 0xFF;	// LED port is set to High (All OFF)
	LATB = 0x00;	// LNA is set to Disable
	LATC = 0x00;	// Relay Port is set to Low (ALL OFF)

	// Set Initialize to 5V range
	set5V();

	// Start to scan the switch and do controller operation.
	while(1) {
		func_sw[getSW()]();
	}
}
